@@ -19,6 +19,9 @@ from traitlets import Dict,Unicode,Instance,TraitType,Type,default
 from notebook.services.contents.manager import ContentsManager
 from collections import namedtuple
 from tornado import gen
+import nbformat
+import json 
+
 from nbformat.v4 import new_notebook
 from .cortx_authenticator import CortxAuthenticator
 
